@@ -14,9 +14,16 @@ class ExplorerContextMixin:
             "can_change": app_settings.EXPLORER_PERMISSION_CHANGE(
                 self.request
             ),
+            "can_manage_connections": app_settings.EXPLORER_PERMISSION_CONNECTIONS(
+                self.request
+            ),
+            "assistant_enabled": app_settings.has_assistant(),
+            "db_connections_enabled": app_settings.db_connections_enabled(),
+            "user_uploads_enabled": app_settings.user_uploads_enabled(),
             "csrf_cookie_name": settings.CSRF_COOKIE_NAME,
-            "csrf_cookie_httponly": settings.CSRF_COOKIE_HTTPONLY,
+            "csrf_token_in_dom": settings.CSRF_COOKIE_HTTPONLY or settings.CSRF_USE_SESSIONS,
             "view_name": self.request.resolver_match.view_name,
+            "hosted": app_settings.EXPLORER_HOSTED
         }
 
     def get_context_data(self, **kwargs):
